@@ -7,10 +7,9 @@ import types
 from collections import OrderedDict, defaultdict
 from importlib import import_module
 
-import six
-
 from .deprecation import Deprecated
 from .preview import PreviewItem
+from .experimental import ExperimentalItem
 from .prompting import prompt_y_n, NoTTYException
 from .util import CLIError, CtxTypeError
 from .arguments import ArgumentRegistry, CLICommandArgument
@@ -23,13 +22,17 @@ from .validators import DefaultInt, DefaultStr
 logger = get_logger(__name__)
 
 
+PREVIEW_EXPERIMENTAL_CONFLICT_ERROR = "Failed to register {} '{}', " \
+                                      "is_preview and is_experimental can't be true at the same time"
+
+
 class CLICommand(object):  # pylint:disable=too-many-instance-attributes
 
     # pylint: disable=unused-argument
     def __init__(self, cli_ctx, name, handler, description=None, table_transformer=None,
                  arguments_loader=None, description_loader=None,
                  formatter_class=None, deprecate_info=None, validator=None, confirmation=None, preview_info=None,
-                 **kwargs):
+                 experimental_info=None, **kwargs):
         """ The command object that goes into the command table.
 
         :param cli_ctx: CLI Context
@@ -52,6 +55,8 @@ class CLICommand(object):  # pylint:disable=too-many-instance-attributes
         :type deprecate_info: str
         :param preview_info: Indicates a command is in preview
         :type preview_info: bool
+        :param experimental_info: Indicates a command is experimental
+        :type experimental_info: bool
         :param validator: The command validator
         :param confirmation: User confirmation required for command
         :type confirmation: bool, str, callable
@@ -71,6 +76,7 @@ class CLICommand(object):  # pylint:disable=too-many-instance-attributes
         self.formatter_class = formatter_class
         self.deprecate_info = deprecate_info
         self.preview_info = preview_info
+        self.experimental_info = experimental_info
         self.confirmation = confirmation
         self.validator = validator
 
@@ -91,6 +97,7 @@ class CLICommand(object):  # pylint:disable=too-many-instance-attributes
             logger.info("Configured default '%s' for arg %s", config_value, arg.name)
             overrides.settings['default'] = DefaultStr(config_value)
             overrides.settings['required'] = False
+            overrides.settings['default_value_source'] = 'Config'
 
     def load_arguments(self):
         if self.arguments_loader:
@@ -143,7 +150,7 @@ class CLICommand(object):  # pylint:disable=too-many-instance-attributes
         if callable(confirmation):
             return confirmation(command_args)
         try:
-            if isinstance(confirmation, six.string_types):
+            if isinstance(confirmation, str):
                 return prompt_y_n(confirmation)
             return prompt_y_n('Are you sure you want to perform this operation?')
         except NoTTYException:
@@ -233,7 +240,7 @@ class CLICommandsLoader(object):
 
     def create_command(self, name, operation, **kwargs):
         """ Constructs the command object that can then be added to the command table """
-        if not isinstance(operation, six.string_types):
+        if not isinstance(operation, str):
             raise ValueError("Operation must be a string. Got '{}'".format(operation))
 
         name = ' '.join(name.split())
@@ -269,9 +276,10 @@ class CLICommandsLoader(object):
                 op = getattr(op, part)
             if isinstance(op, types.FunctionType):
                 return op
-            return six.get_method_function(op)
-        except (ValueError, AttributeError):
-            raise ValueError("The operation '{}' is invalid.".format(operation))
+            # op as types.MethodType
+            return op.__func__
+        except (ValueError, AttributeError) as ex:
+            raise ValueError("The operation '{}' is invalid.".format(operation)) from ex
 
     def deprecate(self, **kwargs):
         kwargs['object_type'] = 'command group'
@@ -300,8 +308,20 @@ class CommandGroup(object):
         Deprecated.ensure_new_style_deprecation(self.command_loader.cli_ctx, self.group_kwargs, 'command group')
         if kwargs['deprecate_info']:
             kwargs['deprecate_info'].target = group_name
-        if kwargs.get('is_preview', False):
+
+        is_preview = kwargs.get('is_preview', False)
+        is_experimental = kwargs.get('is_experimental', False)
+        if is_preview and is_experimental:
+            raise CLIError(PREVIEW_EXPERIMENTAL_CONFLICT_ERROR.format("command group", group_name))
+        if is_preview:
             kwargs['preview_info'] = PreviewItem(
+                cli_ctx=self.command_loader.cli_ctx,
+                target=group_name,
+                object_type='command group'
+            )
+        if is_experimental:
+            kwargs['experimental_info'] = ExperimentalItem(
+                cli_ctx=self.command_loader.cli_ctx,
                 target=group_name,
                 object_type='command group'
             )
@@ -324,20 +344,29 @@ class CommandGroup(object):
         :param kwargs: Kwargs to apply to the command.
                        Possible values: `client_factory`, `arguments_loader`, `description_loader`, `description`,
                        `formatter_class`, `table_transformer`, `deprecate_info`, `validator`, `confirmation`,
-                       `is_preview`.
+                       `is_preview`, `is_experimental`.
         """
         import copy
 
         command_name = '{} {}'.format(self.group_name, name) if self.group_name else name
         command_kwargs = copy.deepcopy(self.group_kwargs)
         command_kwargs.update(kwargs)
-        # don't inherit deprecation info from command group
+
+        # don't inherit deprecation, preview and experimental info from command group
+        # https://github.com/Azure/azure-cli/blob/683b9709b67c4c9e8df92f9fbd53cbf83b6973d3/src/azure-cli-core/azure/cli/core/commands/__init__.py#L1155
         command_kwargs['deprecate_info'] = kwargs.get('deprecate_info', None)
-        if kwargs.get('is_preview', False):
-            command_kwargs['preview_info'] = PreviewItem(
-                self.command_loader.cli_ctx,
-                object_type='command'
-            )
+
+        is_preview = kwargs.get('is_preview', False)
+        is_experimental = kwargs.get('is_experimental', False)
+        if is_preview and is_experimental:
+            raise CLIError(PREVIEW_EXPERIMENTAL_CONFLICT_ERROR.format("command", self.group_name + " " + name))
+
+        command_kwargs['preview_info'] = None
+        if is_preview:
+            command_kwargs['preview_info'] = PreviewItem(self.command_loader.cli_ctx, object_type='command')
+        command_kwargs['experimental_info'] = None
+        if is_experimental:
+            command_kwargs['experimental_info'] = ExperimentalItem(self.command_loader.cli_ctx, object_type='command')
 
         self.command_loader._populate_command_group_table_with_subgroups(' '.join(command_name.split()[:-1]))  # pylint: disable=protected-access
         self.command_loader.command_table[command_name] = self.command_loader.create_command(
