@@ -3,8 +3,6 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from __future__ import unicode_literals, print_function
-
 import unittest
 try:
     import mock
@@ -17,7 +15,7 @@ import argparse
 from knack.arguments import ArgumentsContext
 from knack.commands import CLICommandsLoader, CommandGroup
 
-from tests.util import DummyCLI, redirect_io, remove_space
+from tests.util import DummyCLI, redirect_io, assert_in_multi_line
 
 
 def example_handler(arg1, arg2=None, arg3=None):
@@ -65,9 +63,8 @@ class TestCommandExperimental(unittest.TestCase):
         """ Ensure general warning displayed when running command from an experimental parent group. """
         self.cli_ctx.invoke('grp1 cmd1 -b b'.split())
         actual = self.io.getvalue()
-        expected = "Command group 'grp1' is experimental and not covered by customer support. " \
-                   "Please use with discretion."
-        self.assertIn(remove_space(expected), remove_space(actual))
+        expected = "Command group 'grp1' is experimental and under development."
+        self.assertIn(expected, actual)
 
     @redirect_io
     def test_experimental_command_group_help(self):
@@ -86,15 +83,15 @@ Commands:
     cmd1 [Experimental] : Short summary here.
 
 """.format(self.cli_ctx.name)
-        self.assertEqual(expected, actual)
+        assert_in_multi_line(expected, actual)
 
     @redirect_io
     def test_experimental_command_plain_execute(self):
         """ Ensure general warning displayed when running experimental command. """
         self.cli_ctx.invoke('cmd1 -b b'.split())
         actual = self.io.getvalue()
-        expected = "This command is experimental and not covered by customer support. Please use with discretion."
-        self.assertIn(remove_space(expected), remove_space(actual))
+        expected = "This command is experimental and under development."
+        self.assertIn(expected, actual)
 
 
 class TestCommandGroupExperimental(unittest.TestCase):
@@ -134,12 +131,12 @@ class TestCommandGroupExperimental(unittest.TestCase):
         expected = """
 Group
     cli group1 : A group.
-        This command group is experimental and not covered by customer support. Please use with discretion.
+        This command group is experimental and under development.
 Commands:
     cmd1 : Short summary here.
 
 """.format(self.cli_ctx.name)
-        self.assertIn(remove_space(expected), remove_space(actual))
+        assert_in_multi_line(expected, actual)
 
     @redirect_io
     def test_experimental_command_implicitly(self):
@@ -151,9 +148,9 @@ Commands:
 Command
     {} group1 cmd1 : Short summary here.
         Long summary here. Still long summary.
-        Command group 'group1' is experimental and not covered by customer support. Please use with discretion.
+        Command group 'group1' is experimental and under development.
 """.format(self.cli_ctx.name)
-        self.assertIn(remove_space(expected), remove_space(actual))
+        assert_in_multi_line(expected, actual)
 
 
 class TestArgumentExperimental(unittest.TestCase):
@@ -194,17 +191,16 @@ class TestArgumentExperimental(unittest.TestCase):
         expected = """
 Arguments
     --arg1 [Experimental] [Required] : Arg1.
-        Argument '--arg1' is experimental and not covered by customer support. Please use with discretion.
+        Argument '--arg1' is experimental and under development.
 """.format(self.cli_ctx.name)
-        self.assertIn(remove_space(expected), remove_space(actual))
+        assert_in_multi_line(expected, actual)
 
     @redirect_io
     def test_experimental_arguments_execute(self):
         """ Ensure deprecated arguments can be used. """
         self.cli_ctx.invoke('arg-test --arg1 foo --opt1 bar'.split())
         actual = self.io.getvalue()
-        experimental_expected = "Argument '--arg1' is experimental and not covered by customer support. " \
-                                "Please use with discretion."
+        experimental_expected = "Argument '--arg1' is experimental and under development."
         self.assertIn(experimental_expected, actual)
 
         action_expected = "Side-effect from some original action!"
