@@ -3,8 +3,6 @@
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
 
-from __future__ import unicode_literals, print_function
-
 import unittest
 try:
     import mock
@@ -17,7 +15,7 @@ import argparse
 from knack.arguments import ArgumentsContext
 from knack.commands import CLICommandsLoader, CommandGroup
 
-from tests.util import DummyCLI, redirect_io
+from tests.util import DummyCLI, redirect_io, assert_in_multi_line, disable_color
 
 
 def example_handler(arg1, arg2=None, arg3=None):
@@ -38,7 +36,7 @@ class TestCommandPreview(unittest.TestCase):
 
         class PreviewTestCommandLoader(CLICommandsLoader):
             def load_command_table(self, args):
-                super(PreviewTestCommandLoader, self).load_command_table(args)
+                super().load_command_table(args)
                 with CommandGroup(self, '', '{}#{{}}'.format(__name__)) as g:
                     g.command('cmd1', 'example_handler', is_preview=True)
 
@@ -52,7 +50,7 @@ class TestCommandPreview(unittest.TestCase):
                     c.argument('arg1', options_list=['--arg', '-a'], required=False, type=int, choices=[1, 2, 3])
                     c.argument('arg2', options_list=['-b'], required=True, choices=['a', 'b', 'c'])
 
-                super(PreviewTestCommandLoader, self).load_arguments(command)
+                super().load_arguments(command)
 
         helps['grp1'] = """
     type: group
@@ -77,7 +75,7 @@ Commands:
     cmd1 [Preview] : Short summary here.
 
 """.format(self.cli_ctx.name)
-        self.assertEqual(expected, actual)
+        assert_in_multi_line(expected, actual)
 
     @redirect_io
     def test_preview_command_plain_execute(self):
@@ -87,6 +85,48 @@ Commands:
         expected = "This command is in preview. It may be changed/removed in a future release."
         self.assertIn(expected, actual)
 
+    @redirect_io
+    def test_preview_command_plain_execute_only_show_error(self):
+        """ Ensure warning is suppressed when running preview command. """
+        # Directly use --only-show-errors
+        self.cli_ctx.invoke('cmd1 -b b --only-show-errors'.split())
+        actual = self.io.getvalue()
+        self.assertNotIn("preview", actual)
+
+        # Apply --only-show-errors with config
+        self.cli_ctx.only_show_errors = True
+        self.cli_ctx.config.set_value('core', 'only_show_errors', 'True')
+        self.cli_ctx.invoke('cmd1 -b b'.split())
+        actual = self.io.getvalue()
+        self.assertNotIn("preview", actual)
+        self.cli_ctx.config.set_value('core', 'only_show_errors', '')
+        self.cli_ctx.only_show_errors = False
+
+    @redirect_io
+    @disable_color
+    def test_preview_command_plain_execute_no_color(self):
+        """ Ensure warning is displayed without color. """
+        self.cli_ctx.invoke('cmd1 -b b'.split())
+        actual = self.io.getvalue()
+        self.assertIn("WARNING: This command is in preview. It may be changed/removed in a future release.", actual)
+
+    @redirect_io
+    def test_preview_command_implicitly_execute(self):
+        """ Ensure general warning displayed when running command from a preview parent group. """
+        self.cli_ctx.invoke('grp1 cmd1 -b b'.split())
+        actual = self.io.getvalue()
+        expected = "Command group 'grp1' is in preview. It may be changed/removed in a future release."
+        self.assertIn(expected, actual)
+
+    @redirect_io
+    @disable_color
+    def test_preview_command_implicitly_no_color(self):
+        """ Ensure warning is displayed without color. """
+        self.cli_ctx.invoke('grp1 cmd1 -b b'.split())
+        actual = self.io.getvalue()
+        expected = "WARNING: Command group 'grp1' is in preview. It may be changed/removed in a future release."
+        self.assertIn(expected, actual)
+
 
 class TestCommandGroupPreview(unittest.TestCase):
 
@@ -96,7 +136,7 @@ class TestCommandGroupPreview(unittest.TestCase):
 
         class PreviewTestCommandLoader(CLICommandsLoader):
             def load_command_table(self, args):
-                super(PreviewTestCommandLoader, self).load_command_table(args)
+                super().load_command_table(args)
 
                 with CommandGroup(self, 'group1', '{}#{{}}'.format(__name__), is_preview=True) as g:
                     g.command('cmd1', 'example_handler')
@@ -108,7 +148,7 @@ class TestCommandGroupPreview(unittest.TestCase):
                     c.argument('arg1', options_list=['--arg', '-a'], required=False, type=int, choices=[1, 2, 3])
                     c.argument('arg2', options_list=['-b'], required=True, choices=['a', 'b', 'c'])
 
-                super(PreviewTestCommandLoader, self).load_arguments(command)
+                super().load_arguments(command)
 
         helps['group1'] = """
     type: group
@@ -129,6 +169,23 @@ Group
 Commands:
     cmd1 : Short summary here.
 
+""".format(self.cli_ctx.name)
+        assert_in_multi_line(expected, actual)
+
+    @redirect_io
+    @disable_color
+    def test_preview_command_group_help_plain_no_color(self):
+        """ Ensure warning is displayed without color. """
+        with self.assertRaises(SystemExit):
+            self.cli_ctx.invoke('group1 -h'.split())
+        actual = self.io.getvalue()
+        expected = """
+Group
+    cli group1 : A group.
+        WARNING: This command group is in preview. It may be changed/removed in a future release.
+Commands:
+    cmd1 : Short summary here.
+
 """.format(self.cli_ctx.name)
         self.assertEqual(expected, actual)
 
@@ -141,10 +198,11 @@ Commands:
         expected = """
 Command
     {} group1 cmd1 : Short summary here.
-        Long summary here. Still long summary. Command group 'group1' is in preview. It may be
-        changed/removed in a future release.
+        Long summary here. Still long summary.
+        Command group 'group1' is in preview. It may be changed/removed in a future
+        release.
 """.format(self.cli_ctx.name)
-        self.assertIn(expected, actual)
+        assert_in_multi_line(expected, actual)
 
 
 class TestArgumentPreview(unittest.TestCase):
@@ -159,7 +217,7 @@ class TestArgumentPreview(unittest.TestCase):
 
         class PreviewTestCommandLoader(CLICommandsLoader):
             def load_command_table(self, args):
-                super(PreviewTestCommandLoader, self).load_command_table(args)
+                super().load_command_table(args)
                 with CommandGroup(self, '', '{}#{{}}'.format(__name__)) as g:
                     g.command('arg-test', 'example_arg_handler')
                 return self.command_table
@@ -168,7 +226,7 @@ class TestArgumentPreview(unittest.TestCase):
                 with ArgumentsContext(self, 'arg-test') as c:
                     c.argument('arg1', help='Arg1', is_preview=True, action=LoggerAction)
 
-                super(PreviewTestCommandLoader, self).load_arguments(command)
+                super().load_arguments(command)
 
         helps['grp1'] = """
     type: group
@@ -186,6 +244,20 @@ class TestArgumentPreview(unittest.TestCase):
 Arguments
     --arg1 [Preview] [Required] : Arg1.
         Argument '--arg1' is in preview. It may be changed/removed in a future release.
+""".format(self.cli_ctx.name)
+        assert_in_multi_line(expected, actual)
+
+    @redirect_io
+    @disable_color
+    def test_preview_arguments_command_help_no_color(self):
+        """ Ensure warning is displayed without color. """
+        with self.assertRaises(SystemExit):
+            self.cli_ctx.invoke('arg-test -h'.split())
+        actual = self.io.getvalue()
+        expected = """
+Arguments
+    --arg1 [Preview] [Required] : Arg1.
+        WARNING: Argument '--arg1' is in preview. It may be changed/removed in a future release.
 """.format(self.cli_ctx.name)
         self.assertIn(expected, actual)
 
@@ -200,6 +272,28 @@ Arguments
         action_expected = "Side-effect from some original action!"
         self.assertIn(action_expected, actual)
 
+    @redirect_io
+    @disable_color
+    def test_preview_arguments_execute_no_color(self):
+        """ Ensure warning is displayed without color. """
+        self.cli_ctx.invoke('arg-test --arg1 foo --opt1 bar'.split())
+        actual = self.io.getvalue()
+        preview_expected = "WARNING: Argument '--arg1' is in preview. It may be changed/removed in a future release."
+        self.assertIn(preview_expected, actual)
+
+        action_expected = "Side-effect from some original action!"
+        self.assertIn(action_expected, actual)
+
+
+    @redirect_io
+    def test_preview_arguments_execute_only_show_error(self):
+        """ Ensure warning is suppressed when using preview arguments. """
+        self.cli_ctx.invoke('arg-test --arg1 foo --opt1 bar --only-show-errors'.split())
+        actual = self.io.getvalue()
+        self.assertNotIn("preview", actual)
+
+        action_expected = "Side-effect from some original action!"
+        self.assertIn(action_expected, actual)
 
 if __name__ == '__main__':
     unittest.main()
